@@ -140,7 +140,8 @@ public:
 		symPROPERTY,
 		symORIGINAL,
 		symMODIFIED,
-		symTIMER
+		symTIMER,
+		symBOOL
 	};
 
 	typedef enum symType symType;
